--Author: @MarioKness
--Helpers: @GeekyRafiki (testing + german translation fixes)
--			Maxim_ZG (russian translation fixes)
--			@Vholu-ESO, @Eldwayne and @Batangon (early testing)

DailyHelper = {
	name = "DailyHelper",
	version = "0.2.5",
	variableVersion = 1}

--DEFAULT SETTINGS
DailyHelper.DefaultSettings = {
	AutoQuestCompletion = false,
	AutoDungeonBattleground = true,
	AutoGroupReplacement = false,
	AutoAvA = true,
	ShowGuestCount = true,
	TriggeredShares = true,
	TriggeredDance = true,
	TriggeredCanTp = true}

--CHAT COMMANDS
DailyHelper.ChatCommands = {
	list = "?dh",
	house = "?h",
	shareall = "?s",
	sharezone = "?sz",
	retreat = "?r",
	dance = "?dance",
	quest = "?q",
	vvardenfell = "?v",
	vivec = "?vc",
	cantp = "can tp",
	tp = "?tp"}
	
DailyHelper.SlashCommands = {
	list = "/mkdh_dh",
	house = "/mkdh_h",
	shareall = "/mkdh_s",
	sharezone = "/mkdh_sz",
	retreat = "/mkdh_r",
	quest = "/mkdh_q",
	vvardenfell = "/mkdh_v",
	vivec = "/mkdh_vc"}

--MISC VARS
local CMDcolor = "|cd7c5e9"
local canPortTo = ""
local lastLFGConfirmedMessageTiming  = 0 --fix for the 'LFG ACCEPTED!' printing 5 times

--SETUP SETTINGS MENU
function DailyHelper.SetupSettings()

	local LAM = LibAddonMenu2
	if not LAM then return end
	
	local panelName = "DailyHelperSettings"
	
	local panelData = {
		type = "panel",
		name = "Daily Helper",
		displayName = "Daily Helper",
		author = "MarioKness (EU)",
		version = DailyHelper.version,
		registerForDefaults = true}
	
	LAM:RegisterAddonPanel(panelName, panelData)
	
	local optionsData = {
		{
			type = "checkbox",
			name = GetString(DH_OPT_SKIP_DAILY_DIALOGUE),
			tooltip = GetString(DH_OPT_TOOLTIP_SKIP_DAILY_DIALOUE),
			getFunc = function()
				return DailyHelper.savedVariables.AutoQuestCompletion
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.AutoQuestCompletion = value
			end,
			default = DailyHelper.DefaultSettings.AutoQuestCompletion
		},
		{
			type = "checkbox",
			name = GetString(DH_OPT_CONFIRM_LFG),
			tooltip = GetString(DH_OPT_CONFIRM_LFG),
			getFunc = function()
				return DailyHelper.savedVariables.AutoDungeonBattleground
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.AutoDungeonBattleground = value
			end,
			default = DailyHelper.DefaultSettings.AutoDungeonBattleground
		},
		{
			type = "checkbox",
			name = GetString(DH_OPT_CONFIRM_REPLACEMENT),
			tooltip = GetString(DH_OPT_CONFIRM_REPLACEMENT),
			getFunc = function()
				return DailyHelper.savedVariables.AutoGroupReplacement
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.AutoGroupReplacement = value
			end,
			default = DailyHelper.DefaultSettings.AutoGroupReplacement
		},
		{
			type = "checkbox",
			name = GetString(DH_OPT_CONFIRM_AVA),
			tooltip = GetString(DH_OPT_CONFIRM_AVA),
			getFunc = function()
				return DailyHelper.savedVariables.AutoAvA
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.AutoAvA = value
			end,
			default = DailyHelper.DefaultSettings.AutoAvA
		},
		{
			type = "checkbox",
			name = GetString(DH_OPT_GUEST_COUNT),
			tooltip = GetString(DH_OPT_GUEST_COUNT),
			getFunc = function()
				return DailyHelper.savedVariables.ShowGuestCount
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.ShowGuestCount = value
			end,
			default = DailyHelper.DefaultSettings.ShowGuestCount
		},
		{
			type = "checkbox",
			name = GetString(DH_OPT_CAN_SHARE),
			tooltip = GetString(DH_OPT_CAN_SHARE),
			getFunc = function()
				return DailyHelper.savedVariables.TriggeredShares
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.TriggeredShares = value
			end,
			default = DailyHelper.DefaultSettings.TriggeredShares
		},
		{
			type = "checkbox",
			name = GetString(DH_OPT_CAN_DANCE),
			tooltip = GetString(DH_OPT_CAN_DANCE),
			getFunc = function()
				return DailyHelper.savedVariables.TriggeredDance
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.TriggeredDance = value
			end,
			default = DailyHelper.DefaultSettings.TriggeredDance
		},
		{
			type = "checkbox",
			name = zo_strformat(GetString(DH_OPT_CAN_TP), CMDcolor..DailyHelper.ChatCommands.tp.."|r"),
			tooltip = zo_strformat(GetString(DH_OPT_CAN_TP), CMDcolor..DailyHelper.ChatCommands.tp.."|r"),
			getFunc = function()
				return DailyHelper.savedVariables.TriggeredCanTp
			end,
			setFunc = function(value)
				DailyHelper.savedVariables.TriggeredCanTp = value
			end,
			default = DailyHelper.DefaultSettings.TriggeredCanTp
		}
	}
	
	LAM:RegisterOptionControls(panelName, optionsData)
	
end

--SKIP DAILY QUEST?S COMPLETION DIALOGUE, SAVES A FEW CLICKS. DISABLED BY DEFAULT SETTINGS
function DailyHelper.AutoComplete(eventCode, journalIndex)
	if DailyHelper.savedVariables.AutoQuestCompletion then
		if GetJournalQuestRepeatType(journalIndex) == QUEST_REPEAT_DAILY and GetIsQuestSharable(journalIndex) then
			CompleteQuest(journalIndex)
		end
	end
end

--AUTO-CONFIRM DUNGEONS AND BATTLEGROUNDS
function DailyHelper.AutoReady(eventCode, result)
	if DailyHelper.savedVariables.AutoDungeonBattleground then
		if result==ACTIVITY_FINDER_STATUS_READY_CHECK then
			AcceptLFGReadyCheckNotification()
			--4 seconds cooldown. should avoid printing 5 times in a row
			if lastLFGConfirmedMessageTiming == 0 or lastLFGConfirmedMessageTiming + 4 < os.time(os.date("!*t")) then
				d(GetString(DH_LFG_CONFIRMED))
				lastLFGConfirmedMessageTiming = os.time(os.date("!*t"))
			end
		end
	end
end

--AUTO-CONFIRM GROUP REPLACEMENTS IN DUNGEONS, IF YOU ARE THE LEADER. DISABLED BY DEFAULT SETTINGS
function DailyHelper.FindReplacement(eventCode)
	if DailyHelper.savedVariables.AutoGroupReplacement then
		AcceptActivityFindReplacementNotification()
		d(GetString(DH_DUNGEON_REPLACEMENT_CONFIRMED))
	end
end

--AUTO-CONFIRM AvA CAMPAIGNS
function DailyHelper.AutoCampaign(eventCode, campaignId, isGroup, state)
	if DailyHelper.savedVariables.AutoAvA then
		if state==CAMPAIGN_QUEUE_REQUEST_STATE_CONFIRMING then
			ConfirmCampaignEntry(campaignId, false, true)
			d(GetString(DH_AVA_CONFIRMED))
		end
	end
end

--GET CURRENT GUEST COUNT INSIDE YOUR HOUSE
function DailyHelper.GotGuests(eventCode, newPopulation)
	if DailyHelper.savedVariables.ShowGuestCount then
		if (GetCurrentHouseOwner()==GetUnitDisplayName("player")) and newPopulation > 0 then d(zo_strformat(GetString(DH_HOUSE_GUEST_COUNT), newPopulation-1)) end
	end
end

--TELEPORT(ZONEINDEX)
function DailyHelper.Teleport(zone)
	local porting=false
	--CHECK GROUP MEMBERS FIRST
	for p=1, GetGroupSize() do
		local pTag=GetGroupUnitTagByIndex(p)
		if GetUnitZoneIndex(pTag)==zone and CanJumpToGroupMember(pTag) and porting==false and GetUnitDisplayName(pTag)~=GetUnitDisplayName("player") then
			JumpToGroupMember(GetUnitName(pTag))
			d(zo_strformat(GetString(DH_TELEPORTING_TO_PLAYER_IN_ZONE), GetUnitDisplayName(pTag), GetString(DH_GROUP), GetZoneNameByIndex(zone)))
			porting=true
			break
		end
	end
	--THEN FRIENDS
	if porting == false then
		for f=1, GetNumFriends() do
			local CharInfo = {}
			CharInfo.displayName, CharInfo.Note, CharInfo.status, CharInfo.secsSinceLogoff = GetFriendInfo(f)
			CharInfo.hasCharacter, CharInfo.characterName, CharInfo.zoneName, CharInfo.classType, CharInfo.alliance, CharInfo.level, CharInfo.championRank, CharInfo.zoneId = GetFriendCharacterInfo(f)
			if CharInfo.status~=PLAYER_STATUS_OFFLINE and GetZoneIndex(CharInfo.zoneId)==zone and porting==false and CharInfo.displayName~=GetUnitDisplayName("player") then
				JumpToFriend(CharInfo.displayName)
				d(zo_strformat(GetString(DH_TELEPORTING_TO_PLAYER_IN_ZONE), CharInfo.displayName, GetString(DH_FRIEND), GetZoneNameByIndex(zone)))
				porting=true
				break
			end
		end
	end
	--AND GUILDS
	if porting == false then
		for g=1, GetNumGuilds() do
			for m=1, GetNumGuildMembers(GetGuildId(g)) do
				local CharInfo = {}
				CharInfo.displayName, CharInfo.Note, CharInfo.GuildMemberRankIndex, CharInfo.status, CharInfo.secsSinceLogoff = GetGuildMemberInfo(GetGuildId(g), m)
				CharInfo.hasCharacter, CharInfo.characterName, CharInfo.zoneName, CharInfo.classType, CharInfo.alliance, CharInfo.level, CharInfo.championRank, CharInfo.zoneId = GetGuildMemberCharacterInfo(GetGuildId(g), m)
				CharInfo.guildIndex = g
				if CharInfo.status~=PLAYER_STATUS_OFFLINE and GetZoneIndex(CharInfo.zoneId)==zone and porting==false and CharInfo.displayName~=GetUnitDisplayName("player") then
					JumpToGuildMember(CharInfo.displayName)
					d(zo_strformat(GetString(DH_TELEPORTING_TO_PLAYER_IN_ZONE), CharInfo.displayName, "("..GetGuildName((GetGuildId(g)))..")", GetZoneNameByIndex(zone)))
					porting=true
					break
				end
			end
		end
	end
	if porting == true then return end

	--FOUND NOBODY, CHECK IF ZONE IS A SUBZONE
	if porting == false then d(zo_strformat(GetString(DH_NOBODY_TO_TELEPORT_TO_IN_ZONE), GetZoneNameByIndex(zone))) end
	local ParentZoneId = 0
	if ParentZoneId == 0 and GetZoneId(zone) == 1027 then ParentZoneId = 1011 end --Artaeum to Summerset
	if ParentZoneId == 0 and GetZoneId(zone) == 1016 then ParentZoneId = 1027 end --Traitor's Vault to Artaeum
	if ParentZoneId == 0 and GetZoneId(zone) == 1161 then ParentZoneId = 1160 end --Blackreach: Greymoor caverns to Western Skyrim
	if ParentZoneId == 0 and GetZoneId(zone) == 1208 then ParentZoneId = 1207 end --Blackreach: Arkthzand cavern to The Reach
	if ParentZoneId == 0 then ParentZoneId = GetParentZoneId(GetZoneId(zone)) end
	if ParentZoneId ~= 0 and ParentZoneId ~= GetZoneId(zone) and GetZoneIndex(ParentZoneId) ~= GetUnitZoneIndex("player") then DailyHelper.Teleport(GetZoneIndex(ParentZoneId)) end
end

--SHARE ALL YOUR DAILIES. CAN BE TRIGGERED BY GROUP MEMBERS, UNLESS DISABLED IN SETTINGS.
function DailyHelper.ShareAllDailies()
	local quest_count = 0
	for i = 1, GetNumJournalQuests() do
		if GetJournalQuestRepeatType(i) == QUEST_REPEAT_DAILY and GetIsQuestSharable(i) then
			ShareQuest(i)
			d(zo_strformat(GetString(DH_SHARED_QUEST_NAME), GetJournalQuestName(i)))
			quest_count=quest_count+1
		end
	end
	if quest_count == 0 then d(GetString(DH_NO_QUESTS_TO_SHARE)) end
	if quest_count > 0 then d(zo_strformat(GetString(DH_SHARED_QUESTS_COUNT), quest_count)) end
end

--SHARE DAILIES FROM YOUR CURRENT ZONE. CAN BE TRIGGERED BY GROUP MEMBERS, UNLESS DISABLED IN SETTINGS.
function DailyHelper.ShareZoneDailies()
	local pZone=GetPlayerActiveZoneName()
	local quest_count = 0
	for i = 1, GetNumJournalQuests() do
		if GetJournalQuestRepeatType(i) == QUEST_REPEAT_DAILY and GetIsQuestSharable(i) then
			if string.find(GetJournalQuestLocationInfo(i), pZone) then
				ShareQuest(i)
				d(zo_strformat(GetString(DH_SHARED_QUEST_NAME), GetJournalQuestName(i)))
				quest_count=quest_count+1
			end
		end
	end
	if quest_count == 0 then d(zo_strformat(GetString(DH_NO_ZONE_QUESTS_TO_SHARE), pZone)) end
	if quest_count > 0 then d(zo_strformat(GetString(DH_SHARED_ZONE_QUESTS_COUNT), quest_count, pZone)) end
end

--SHOW CHAT COMMAND LIST
function DailyHelper.PrintCMDList()
	d(GetString(DH_DHCMD))
	d(CMDcolor..DailyHelper.ChatCommands.house.."|r, "..CMDcolor..DailyHelper.SlashCommands.house.."|r "..GetString(DH_CHAT_CMD_GO_HOME))
	d(CMDcolor..DailyHelper.ChatCommands.shareall.."|r, "..CMDcolor..DailyHelper.SlashCommands.shareall.."|r "..GetString(DH_CHAT_CMD_SHARE_ALL))
	d(CMDcolor..DailyHelper.ChatCommands.sharezone.."|r, "..CMDcolor..DailyHelper.SlashCommands.sharezone.."|r "..GetString(DH_CHAT_CMD_SHARE_ZONE))
	d(CMDcolor..DailyHelper.ChatCommands.retreat.."|r, "..CMDcolor..DailyHelper.SlashCommands.retreat.."|r "..GetString(DH_CHAT_CMD_RETREAT))
	d(CMDcolor..DailyHelper.ChatCommands.dance.."|r "..GetString(DH_CHAT_CMD_DANCE))
	d(CMDcolor..DailyHelper.ChatCommands.quest.."|r, "..CMDcolor..DailyHelper.SlashCommands.quest.."|r "..GetString(DH_CHAT_CMD_GO_TO_QUEST))
	d(CMDcolor..DailyHelper.ChatCommands.vvardenfell.."|r, "..CMDcolor..DailyHelper.SlashCommands.vvardenfell.."|r "..GetString(DH_CHAT_CMD_GO_VVARDENFELL))
	d(CMDcolor..DailyHelper.ChatCommands.vivec.."|r, "..CMDcolor..DailyHelper.SlashCommands.vivec.."|r "..GetString(DH_CHAT_CMD_GO_VIVEC))
	d(CMDcolor..DailyHelper.ChatCommands.cantp.."|r "..zo_strformat(GetString(DH_CHAT_CMD_CAN_TP), CMDcolor..DailyHelper.ChatCommands.tp.."|r"))
	d(CMDcolor..DailyHelper.ChatCommands.tp.."|r "..zo_strformat(GetString(DH_CHAT_CMD_TP), CMDcolor..DailyHelper.ChatCommands.cantp.."|r"))
end

--DANCE. CAN BE TRIGGERED BY GROUP MEMBERS, UNLESS DISABLED IN SETTINGS.
function DailyHelper.Dance(emoteIndex) --/dance is 72 and is race-based
	PlayEmoteByIndex(emoteIndex)
end

--TELEPORT TO VVARDENFELL
function DailyHelper.Vvardenfell()
	DailyHelper.Teleport(467)
end

--TELEPORT TO VIVEC CITY
function DailyHelper.Vivec()
	if HasCompletedFastTravelNodePOI(284) then
		FastTravelToNode(284)
		d(zo_strformat(GetString(DH_TELEPORTING_TO_VIVEC), GetRecallCost(284)))
	end
	--don't have the wayshrine
	if not HasCompletedFastTravelNodePOI(284) then d(GetString(DH_VIVEC_NOT_DISCOVERED)) end
end

--TELEPORT TO TRACKED QUEST
function DailyHelper.QuestTP()
	--find the tracked quest, if any
	for q = 1, GetNumJournalQuests() do
		local QuestInfo = {}
		QuestInfo.questName, QuestInfo.backgroundText, QuestInfo.activeStepText, QuestInfo.activeStepType, QuestInfo.activeStepTrackerOverrideText, QuestInfo.completed, QuestInfo.tracked, QuestInfo.questLevel, QuestInfo.pushed, QuestInfo.questType, QuestInfo.instanceDisplayType = GetJournalQuestInfo(q)
		if QuestInfo.tracked then
			--if NOT pvp, trial etc
			if not (QuestInfo.instanceDisplayType==9 or QuestInfo.instanceDisplayType==2 or QuestInfo.instanceDisplayType==8 or QuestInfo.instanceDisplayType==3 or QuestInfo.instanceDisplayType==1) then
				ZO_WorldMap_ShowQuestOnMap(q)
				DailyHelper.Teleport(GetCurrentMapZoneIndex())
				ZO_WorldMap_HideWorldMap()
			end
			--else IT WILL FAIL!
			if (QuestInfo.instanceDisplayType==9 or QuestInfo.instanceDisplayType==2 or QuestInfo.instanceDisplayType==8 or QuestInfo.instanceDisplayType==3 or QuestInfo.instanceDisplayType==1) then
				d(GetString(DH_CANT_TP_TO_THAT_ZONE))
			end
			break --found the tracked quest
		end
	end
end

--RETREAT BETWEEN CYRODIIL AND IMPERIAL CITY, NO NEED FOR RECALL STONES OR SIGILS OF RETREAT
function DailyHelper.Retreat()
	if (IsInAvAZone()) then
		--if in Cyrodiil, go to CP Imperial City
		if (IsInCyrodiil()) then
			--CP Imperial City's ID is 1
			d(zo_strformat(GetString(DH_JOINING_CAMPAIGN_NAME), GetCampaignName(GetSelectionCampaignId(1))))
			QueueForCampaign(GetSelectionCampaignId(1), false)
		end
		--else go to Standard Cyrodiil
		if (not IsInCyrodiil()) then
			--Standard Cyrodiil'ID is 3
			d(zo_strformat(GetString(DH_JOINING_CAMPAIGN_NAME), GetCampaignName(GetSelectionCampaignId(3))))
			QueueForCampaign(GetSelectionCampaignId(3), false)
		end
	end
	if (not IsInAvAZone()) then 
		d(zo_strformat(GetString(DH_THAT_CMD_NEEDS_AVA_ZONE), CMDcolor..DailyHelper.ChatCommands.retreat.."|r"))
	end
end

--GO HOME
function DailyHelper.GoHome()
	d(GetString(DH_GOING_HOME))
	RequestJumpToHouse(GetHousingPrimaryHouse())
end


----------------------------------------------------

		
--CHECK FOR CHAT COMMANDS
function DailyHelper.ChatCMD(eventCode, channelType, fromName, text, isCustomerService, fromDisplayName)

	--command list
	if (fromDisplayName==GetUnitDisplayName("player") and (text:lower()==DailyHelper.ChatCommands.list)) then
		DailyHelper.PrintCMDList()
	end
	
	--------------------------------------------------------------------
	--dance
		--If used correctly
	if text:lower()==DailyHelper.ChatCommands.dance and channelType == CHAT_CHANNEL_PARTY and GetGroupSize()>1 then
		if DailyHelper.savedVariables.TriggeredDance or fromDisplayName==GetUnitDisplayName("player") then
			DailyHelper.Dance(72)
		end
	end
		--If You're not in a group OR not using group chat
	if text:lower()==DailyHelper.ChatCommands.dance and (channelType ~= CHAT_CHANNEL_PARTY or GetGroupSize()<2) and fromDisplayName==GetUnitDisplayName("player") then
		d(zo_strformat(GetString(DH_THAT_CMD_NEEDS_GROUP_CHAT), CMDcolor..DailyHelper.ChatCommands.dance.."|r"))
	end
	
	--------------------------------------------------------------------
	--go to Vvardenfell, because EVERYONE loves Vvardenfell!
	if (fromDisplayName==GetUnitDisplayName("player") and (text:lower()==DailyHelper.ChatCommands.vvardenfell)) then
		DailyHelper.Vvardenfell()
	end
	
	--------------------------------------------------------------------
	--go to Vivec City's wayshrine (costs gold! try the Vvardenfell one first)
	if (fromDisplayName==GetUnitDisplayName("player") and (text:lower()==DailyHelper.ChatCommands.vivec)) then
		DailyHelper.Vivec()
	end
	
	--------------------------------------------------------------------
	--go to your currently tracked quest's zone
	if (fromDisplayName==GetUnitDisplayName("player") and (text:lower()==DailyHelper.ChatCommands.quest)) then
		DailyHelper.QuestTP()
	end
	
	--------------------------------------------------------------------
	--retreat from AvA, teleporting between Cyrodiil and IC. 2nd argument is false to not queue your group members
	if (fromDisplayName==GetUnitDisplayName("player") and (text:lower()==DailyHelper.ChatCommands.retreat)) then
		DailyHelper.Retreat()
	end
	
	--------------------------------------------------------------------
	--teleport to your main house
	if (fromDisplayName==GetUnitDisplayName("player") and (text:lower()==DailyHelper.ChatCommands.house)) then
		DailyHelper.GoHome()
	end
	
	--------------------------------------------------------------------
	--share all dailies. If you write it in group chat, group members with the addon installed will share their dailies too! unless they disabled that.
	if text:lower()==DailyHelper.ChatCommands.shareall then
		if (channelType == CHAT_CHANNEL_PARTY and DailyHelper.savedVariables.TriggeredShares and fromDisplayName~=GetUnitDisplayName("player")) or (fromDisplayName==GetUnitDisplayName("player")) then
			DailyHelper.ShareAllDailies()
		end
	end
	
	--------------------------------------------------------------------
	--share all dailies from the current zone. If you write it in group chat, group members with the addon installed will share their dailies too! unless they disabled that.
		--note that group members will share from THEIR current zone!
	if text:lower()==DailyHelper.ChatCommands.sharezone then
		if (channelType == CHAT_CHANNEL_PARTY and DailyHelper.savedVariables.TriggeredShares and fromDisplayName~=GetUnitDisplayName("player")) or (fromDisplayName==GetUnitDisplayName("player")) then
			DailyHelper.ShareZoneDailies()
		end
	end
	
	--------------------------------------------------------------------
	--can tp --> ?tp
	if (channelType == CHAT_CHANNEL_PARTY and (text:lower()=="can tp") and fromDisplayName~=GetUnitDisplayName("player")) and canPortTo~=fromDisplayName and DailyHelper.savedVariables.TriggeredCanTp then
		d(zo_strformat(GetString(DH_WANT_TO_TP), fromDisplayName, CMDcolor..DailyHelper.ChatCommands.tp.."|r"))
		canPortTo=fromDisplayName
	end
	if (text:lower()=="?tp") and fromDisplayName==GetUnitDisplayName("player") and canPortTo~="" then
		JumpToGroupMember(canPortTo)
		d(zo_strformat(GetString(DH_TELEPORTING_TO_PLAYER), canPortTo))
	end
	
end


--INITIALIZE
function DailyHelper:Initialize()
	DailyHelper.savedVariables = ZO_SavedVars:NewAccountWide("DailyHelperVars", DailyHelper.variableVersion, nil, DailyHelper.DefaultSettings)
	DailyHelper.SetupSettings()
	EVENT_MANAGER:RegisterForEvent(DailyHelper.name, EVENT_QUEST_COMPLETE_DIALOG, DailyHelper.AutoComplete)
	EVENT_MANAGER:RegisterForEvent(DailyHelper.name, EVENT_ACTIVITY_FINDER_STATUS_UPDATE, DailyHelper.AutoReady)
	EVENT_MANAGER:RegisterForEvent(DailyHelper.name, EVENT_CAMPAIGN_QUEUE_STATE_CHANGED, DailyHelper.AutoCampaign)
	EVENT_MANAGER:RegisterForEvent(DailyHelper.name, EVENT_CHAT_MESSAGE_CHANNEL, DailyHelper.ChatCMD)
	EVENT_MANAGER:RegisterForEvent(DailyHelper.name, EVENT_GROUPING_TOOLS_FIND_REPLACEMENT_NOTIFICATION_NEW, DailyHelper.FindReplacement)
	EVENT_MANAGER:RegisterForEvent(DailyHelper.name, EVENT_HOUSING_POPULATION_CHANGED, DailyHelper.GotGuests)
	SLASH_COMMANDS[DailyHelper.SlashCommands.list] = DailyHelper.PrintCMDList
	SLASH_COMMANDS[DailyHelper.SlashCommands.house] = DailyHelper.GoHome
	SLASH_COMMANDS[DailyHelper.SlashCommands.shareall] = DailyHelper.ShareAllDailies
	SLASH_COMMANDS[DailyHelper.SlashCommands.sharezone] = DailyHelper.ShareZoneDailies
	SLASH_COMMANDS[DailyHelper.SlashCommands.retreat] = DailyHelper.Retreat
	SLASH_COMMANDS[DailyHelper.SlashCommands.quest] = DailyHelper.QuestTP
	SLASH_COMMANDS[DailyHelper.SlashCommands.vvardenfell] = DailyHelper.Vvardenfell
	SLASH_COMMANDS[DailyHelper.SlashCommands.vivec] = DailyHelper.Vivec
end

function DailyHelper.OnAddOnLoaded(event, addonName)
	if addonName == DailyHelper.name then
		EVENT_MANAGER:UnregisterForEvent(DailyHelper.name, EVENT_ADD_ON_LOADED)
		DailyHelper:Initialize()
	end
end

EVENT_MANAGER:RegisterForEvent(DailyHelper.name, EVENT_ADD_ON_LOADED, DailyHelper.OnAddOnLoaded)
